@@ -1,5 +1,3 @@
-import pandas as pd
-import numpy as np
 
 def Convert(lst):
     res_dct = map(lambda i: (lst[i], lst[i+1]), range(len(lst)-1)[::2])
@@ -19,21 +17,26 @@ def get_index(x_data):
     return lst,column_name
 
 def df_to_dictionary(x_data,y_data,x_data_len):
-    try:
-        indexs,column_name = get_index(x_data)
-        ydata = []
-        xdata = []
-        for i in y_data:
+    indexs,column_names = get_index(x_data)
+    ydata = []
+    xdata = []
+    for i in y_data:
+        try:
             ydata.append(i)
-        for i in range(0,x_data_len):
+        except Exception as e:
+            Warning(e)
+            print(e)
+    for i in range(0,x_data_len):
+        try:
             col = x_data.iloc[i,]
             number = 0
-            for num in col:
-                column_name.insert(indexs[number],col[number])
-                number +=1
 
-            xdata.append(Convert(column_name))
-    except Exception as e:
-        Warning(e)
-        print(e)
+            for num in indexs:
+                column_names.insert(num,col[number])
+                number +=1
+            xdata.append(Convert(column_names))
+            indexs,column_names = get_index(x_data)
+        except Exception as e:
+            Warning(e)
+            print(e)
     return xdata,ydata
